==> primefaces-extensions-8.0.jar: META-INF/resources/primefaces-extensions/waypoint/waypoint.js <==
/*
 jQuery Waypoints - v2.0.5
Copyright (c) 2011-2014 Caleb Troughton
Licensed under the MIT license.
https://github.com/imakewebthings/jquery-waypoints/blob/master/licenses.txt
*/
var oldOffset=jQuery.fn.offset;jQuery.fn.offset=function(){var e=this[0],m={top:0,left:0};return e&&e.nodeType&&jQuery.contains((e.ownerDocument||document).documentElement,e)?oldOffset.apply(this,arguments):m};
(function(){var e=[].indexOf||function(c){for(var g=0,e=this.length;g<e;g++)if(g in this&&this[g]===c)return g;return-1},m=[].slice;(function(c,g){return"function"===typeof define&&define.amd?define("waypoints",["jquery"],function(e){return g(e,c)}):g(c.jQuery,c)})(window,function(c,g){var q=c(g);var r=0<=e.call(g,"ontouchstart");var n={horizontal:{},vertical:{}};var u=1;var p={};var v=1;var w=function(){function a(a){var b=this;this.$element=a;this.element=a[0];this.didScroll=this.didResize=!1;this.id=
"context"+u++;this.oldScroll={x:a.scrollLeft(),y:a.scrollTop()};this.waypoints={horizontal:{},vertical:{}};this.element["waypoints-context-id"]=this.id;p[this.id]=this;a.on("scroll.waypoints",function(){if(!b.didScroll&&!r)return b.didScroll=!0,g.setTimeout(function(){b.doScroll();return b.didScroll=!1},c.waypoints.settings.scrollThrottle)});a.on("resize.waypoints",function(){if(!b.didResize)return b.didResize=!0,g.setTimeout(function(){c.waypoints("refresh");return b.didResize=!1},c.waypoints.settings.resizeThrottle)})}
a.prototype.doScroll=function(){var a=this;var d={horizontal:{newScroll:this.$element.scrollLeft(),oldScroll:this.oldScroll.x,forward:"right",backward:"left"},vertical:{newScroll:this.$element.scrollTop(),oldScroll:this.oldScroll.y,forward:"down",backward:"up"}};!r||d.vertical.oldScroll&&d.vertical.newScroll||c.waypoints("refresh");c.each(d,function(b,d){var f;var h=[];var e=(f=d.newScroll>d.oldScroll)?d.forward:d.backward;c.each(a.waypoints[b],function(a,b){var c,f;if(d.oldScroll<(c=b.offset)&&c<=
d.newScroll||d.newScroll<(f=b.offset)&&f<=d.oldScroll)return h.push(b)});h.sort(function(a,b){return a.offset-b.offset});f||h.reverse();return c.each(h,function(a,b){if(b.options.continuous||a===h.length-1)return b.trigger([e])})});return this.oldScroll={x:d.horizontal.newScroll,y:d.vertical.newScroll}};a.prototype.refresh=function(){var a=this;var d=c.isWindow(this.element);var f=this.$element.offset();this.doScroll();f={horizontal:{contextOffset:d?0:f.left,contextScroll:d?0:this.oldScroll.x,contextDimension:this.$element.width(),
oldScroll:this.oldScroll.x,forward:"right",backward:"left",offsetProp:"left"},vertical:{contextOffset:d?0:f.top,contextScroll:d?0:this.oldScroll.y,contextDimension:d?c.waypoints("viewportHeight"):this.$element.height(),oldScroll:this.oldScroll.y,forward:"down",backward:"up",offsetProp:"top"}};return c.each(f,function(b,d){return c.each(a.waypoints[b],function(a,b){var f,h;a=b.options.offset;var e=b.offset;var g=c.isWindow(b.element)?0:b.$element.offset()[d.offsetProp];c.isFunction(a)?a=a.apply(b.element):
"string"===typeof a&&(a=parseFloat(a),-1<b.options.offset.indexOf("%")&&(a=Math.ceil(d.contextDimension*a/100)));b.offset=g-d.contextOffset+d.contextScroll-a;if((!b.options.onlyOnScroll||null==e)&&b.enabled){if(null!==e&&e<(f=d.oldScroll)&&f<=b.offset)return b.trigger([d.backward]);if(null!==e&&e>(h=d.oldScroll)&&h>=b.offset||null===e&&d.oldScroll>=b.offset)return b.trigger([d.forward])}})})};a.prototype.checkEmpty=function(){if(c.isEmptyObject(this.waypoints.horizontal)&&c.isEmptyObject(this.waypoints.vertical))return this.$element.off("resize.waypoints scroll.waypoints"),
delete p[this.id]};return a}();var t=function(){function a(a,d,f){var b;"bottom-in-view"===f.offset&&(f.offset=function(){var a=c.waypoints("viewportHeight");c.isWindow(d.element)||(a=d.$element.height());return a-c(this).outerHeight()});this.$element=a;this.element=a[0];this.axis=f.horizontal?"horizontal":"vertical";this.callback=f.handler;this.context=d;this.enabled=f.enabled;this.id="waypoints"+v++;this.offset=null;this.options=f;d.waypoints[this.axis][this.id]=this;n[this.axis][this.id]=this;
a=null!=(b=this.element["waypoints-waypoint-ids"])?b:[];a.push(this.id);this.element["waypoints-waypoint-ids"]=a}a.prototype.trigger=function(a){if(this.enabled&&(null!=this.callback&&this.callback.apply(this.element,a),this.options.triggerOnce))return this.destroy()};a.prototype.disable=function(){return this.enabled=!1};a.prototype.enable=function(){this.context.refresh();return this.enabled=!0};a.prototype.destroy=function(){delete n[this.axis][this.id];delete this.context.waypoints[this.axis][this.id];
return this.context.checkEmpty()};a.getWaypointsByElement=function(a){a=a["waypoints-waypoint-ids"];if(!a)return[];var b=c.extend({},n.horizontal,n.vertical);return c.map(a,function(a){return b[a]})};return a}();var l={init:function(a,b){b=c.extend({},c.fn.waypoint.defaults,b);null==b.handler&&(b.handler=a);this.each(function(){var a;var f=c(this);var h=null!=(a=b.context)?a:c.fn.waypoint.defaults.context;c.isWindow(h)||(h=f.closest(h));h=c(h);(a=p[h[0]["waypoints-context-id"]])||(a=new w(h));return new t(f,
a,b)});c.waypoints("refresh");return this},disable:function(){return l._invoke.call(this,"disable")},enable:function(){return l._invoke.call(this,"enable")},destroy:function(){return l._invoke.call(this,"destroy")},prev:function(a,b){return l._traverse.call(this,a,b,function(a,b,c){if(0<b)return a.push(c[b-1])})},next:function(a,b){return l._traverse.call(this,a,b,function(a,b,c){if(b<c.length-1)return a.push(c[b+1])})},_traverse:function(a,b,d){null==a&&(a="vertical");null==b&&(b=g);var f=k.aggregate(b);
var e=[];this.each(function(){var b=c.inArray(this,f[a]);return d(e,b,f[a])});return this.pushStack(e)},_invoke:function(a){this.each(function(){var b=t.getWaypointsByElement(this);return c.each(b,function(b,c){c[a]();return!0})});return this}};c.fn.waypoint=function(){var a=arguments[0];var b=2<=arguments.length?m.call(arguments,1):[];return l[a]?l[a].apply(this,b):c.isFunction(a)?l.init.apply(this,arguments):c.isPlainObject(a)?l.init.apply(this,[null,a]):a?c.on("error",function(){alert("The "+a+
" method does not exist in jQuery Waypoints.")}):c.on("error",function(){alert("jQuery Waypoints needs a callback function or handler option.")})};c.fn.waypoint.defaults={context:g,continuous:!0,enabled:!0,horizontal:!1,offset:0,triggerOnce:!1};var k={refresh:function(){return c.each(p,function(a,b){return b.refresh()})},viewportHeight:function(){var a;return null!=(a=g.innerHeight)?a:q.height()},aggregate:function(a){var b;var d=n;a&&(d=null!=(b=p[c(a)[0]["waypoints-context-id"]])?b.waypoints:void 0);
if(!d)return[];var f={horizontal:[],vertical:[]};c.each(f,function(a,b){c.each(d[a],function(a,c){return b.push(c)});b.sort(function(a,b){return a.offset-b.offset});f[a]=c.map(b,function(a){return a.element});return f[a]=c.uniqueSort(f[a])});return f},above:function(a){null==a&&(a=g);return k._filter(a,"vertical",function(a,c){return c.offset<=a.oldScroll.y})},below:function(a){null==a&&(a=g);return k._filter(a,"vertical",function(a,c){return c.offset>a.oldScroll.y})},left:function(a){null==a&&(a=
g);return k._filter(a,"horizontal",function(a,c){return c.offset<=a.oldScroll.x})},right:function(a){null==a&&(a=g);return k._filter(a,"horizontal",function(a,c){return c.offset>a.oldScroll.x})},enable:function(){return k._invoke("enable")},disable:function(){return k._invoke("disable")},destroy:function(){return k._invoke("destroy")},extendFn:function(a,b){return l[a]=b},_invoke:function(a){var b=c.extend({},n.vertical,n.horizontal);return c.each(b,function(b,c){c[a]();return!0})},_filter:function(a,
b,d){var f=p[c(a)[0]["waypoints-context-id"]];if(!f)return[];var e=[];c.each(f.waypoints[b],function(a,b){if(d(f,b))return e.push(b)});e.sort(function(a,b){return a.offset-b.offset});return c.map(e,function(a){return a.element})}};c.waypoints=function(){var a=arguments[0];var b=2<=arguments.length?m.call(arguments,1):[];return k[a]?k[a].apply(null,b):k.aggregate.call(null,a)};c.waypoints.settings={resizeThrottle:100,scrollThrottle:30};return q.on("load.waypoints",function(){return c.waypoints("refresh")})})}).call(this);
PrimeFaces.widget.ExtWaypoint=PrimeFaces.widget.BaseWidget.extend({init:function(e){this._super(e);this.cfg=e;this.id=e.id;this.target=PrimeFaces.expressions.SearchExpressionFacade.resolveComponentsAsSelector(this.cfg.target);delete this.cfg.target;this.cfg.context&&(this.cfg.context=PrimeFaces.expressions.SearchExpressionFacade.resolveComponentsAsSelector(this.cfg.context));this.destroy().create()},destroy:function(){this.target.waypoint("destroy");return this},disable:function(){this.target.waypoint("disable");
return this},enable:function(){this.target.waypoint("enable");return this},create:function(){var e=this;this.target.waypoint(function(m){e.reached(m,this)},this.cfg)},refresh:function(){$.waypoints("refresh")},reached:function(e,m){e={params:[{name:this.id+"_direction",value:e},{name:this.id+"_waypointId",value:$(m).attr("id")}],direction:e,waypoint:m};this.callBehavior("reached",e)}});

==> primefaces-extensions-8.0.3.jar: META-INF/resources/primefaces-extensions/waypoint/waypoint.js <==
/*
 jQuery Waypoints - v2.0.5
Copyright (c) 2011-2014 Caleb Troughton
Licensed under the MIT license.
https://github.com/imakewebthings/jquery-waypoints/blob/master/licenses.txt
*/
var oldOffset=jQuery.fn.offset;jQuery.fn.offset=function(){var e=this[0],m={top:0,left:0};return e&&e.nodeType&&jQuery.contains((e.ownerDocument||document).documentElement,e)?oldOffset.apply(this,arguments):m};
(function(){var e=[].indexOf||function(c){for(var g=0,e=this.length;g<e;g++)if(g in this&&this[g]===c)return g;return-1},m=[].slice;(function(c,g){return"function"===typeof define&&define.amd?define("waypoints",["jquery"],function(e){return g(e,c)}):g(c.jQuery,c)})(window,function(c,g){var q=c(g);var r=0<=e.call(g,"ontouchstart");var n={horizontal:{},vertical:{}};var u=1;var p={};var v=1;var w=function(){function a(a){var b=this;this.$element=a;this.element=a[0];this.didScroll=this.didResize=!1;this.id=
"context"+u++;this.oldScroll={x:a.scrollLeft(),y:a.scrollTop()};this.waypoints={horizontal:{},vertical:{}};this.element["waypoints-context-id"]=this.id;p[this.id]=this;a.on("scroll.waypoints",function(){if(!b.didScroll&&!r)return b.didScroll=!0,g.setTimeout(function(){b.doScroll();return b.didScroll=!1},c.waypoints.settings.scrollThrottle)});a.on("resize.waypoints",function(){if(!b.didResize)return b.didResize=!0,g.setTimeout(function(){c.waypoints("refresh");return b.didResize=!1},c.waypoints.settings.resizeThrottle)})}
a.prototype.doScroll=function(){var a=this;var d={horizontal:{newScroll:this.$element.scrollLeft(),oldScroll:this.oldScroll.x,forward:"right",backward:"left"},vertical:{newScroll:this.$element.scrollTop(),oldScroll:this.oldScroll.y,forward:"down",backward:"up"}};!r||d.vertical.oldScroll&&d.vertical.newScroll||c.waypoints("refresh");c.each(d,function(b,d){var f;var h=[];var e=(f=d.newScroll>d.oldScroll)?d.forward:d.backward;c.each(a.waypoints[b],function(a,b){var c,f;if(d.oldScroll<(c=b.offset)&&c<=
d.newScroll||d.newScroll<(f=b.offset)&&f<=d.oldScroll)return h.push(b)});h.sort(function(a,b){return a.offset-b.offset});f||h.reverse();return c.each(h,function(a,b){if(b.options.continuous||a===h.length-1)return b.trigger([e])})});return this.oldScroll={x:d.horizontal.newScroll,y:d.vertical.newScroll}};a.prototype.refresh=function(){var a=this;var d=c.isWindow(this.element);var f=this.$element.offset();this.doScroll();f={horizontal:{contextOffset:d?0:f.left,contextScroll:d?0:this.oldScroll.x,contextDimension:this.$element.width(),
oldScroll:this.oldScroll.x,forward:"right",backward:"left",offsetProp:"left"},vertical:{contextOffset:d?0:f.top,contextScroll:d?0:this.oldScroll.y,contextDimension:d?c.waypoints("viewportHeight"):this.$element.height(),oldScroll:this.oldScroll.y,forward:"down",backward:"up",offsetProp:"top"}};return c.each(f,function(b,d){return c.each(a.waypoints[b],function(a,b){var f,h;a=b.options.offset;var e=b.offset;var g=c.isWindow(b.element)?0:b.$element.offset()[d.offsetProp];"function"===typeof a?a=a.apply(b.element):
"string"===typeof a&&(a=parseFloat(a),-1<b.options.offset.indexOf("%")&&(a=Math.ceil(d.contextDimension*a/100)));b.offset=g-d.contextOffset+d.contextScroll-a;if((!b.options.onlyOnScroll||null==e)&&b.enabled){if(null!==e&&e<(f=d.oldScroll)&&f<=b.offset)return b.trigger([d.backward]);if(null!==e&&e>(h=d.oldScroll)&&h>=b.offset||null===e&&d.oldScroll>=b.offset)return b.trigger([d.forward])}})})};a.prototype.checkEmpty=function(){if(c.isEmptyObject(this.waypoints.horizontal)&&c.isEmptyObject(this.waypoints.vertical))return this.$element.off("resize.waypoints scroll.waypoints"),
delete p[this.id]};return a}();var t=function(){function a(a,d,f){var b;"bottom-in-view"===f.offset&&(f.offset=function(){var a=c.waypoints("viewportHeight");c.isWindow(d.element)||(a=d.$element.height());return a-c(this).outerHeight()});this.$element=a;this.element=a[0];this.axis=f.horizontal?"horizontal":"vertical";this.callback=f.handler;this.context=d;this.enabled=f.enabled;this.id="waypoints"+v++;this.offset=null;this.options=f;d.waypoints[this.axis][this.id]=this;n[this.axis][this.id]=this;
a=null!=(b=this.element["waypoints-waypoint-ids"])?b:[];a.push(this.id);this.element["waypoints-waypoint-ids"]=a}a.prototype.trigger=function(a){if(this.enabled&&(null!=this.callback&&this.callback.apply(this.element,a),this.options.triggerOnce))return this.destroy()};a.prototype.disable=function(){return this.enabled=!1};a.prototype.enable=function(){this.context.refresh();return this.enabled=!0};a.prototype.destroy=function(){delete n[this.axis][this.id];delete this.context.waypoints[this.axis][this.id];
return this.context.checkEmpty()};a.getWaypointsByElement=function(a){a=a["waypoints-waypoint-ids"];if(!a)return[];var b=c.extend({},n.horizontal,n.vertical);return c.map(a,function(a){return b[a]})};return a}();var l={init:function(a,b){b=c.extend({},c.fn.waypoint.defaults,b);null==b.handler&&(b.handler=a);this.each(function(){var a;var f=c(this);var h=null!=(a=b.context)?a:c.fn.waypoint.defaults.context;c.isWindow(h)||(h=f.closest(h));h=c(h);(a=p[h[0]["waypoints-context-id"]])||(a=new w(h));return new t(f,
a,b)});c.waypoints("refresh");return this},disable:function(){return l._invoke.call(this,"disable")},enable:function(){return l._invoke.call(this,"enable")},destroy:function(){return l._invoke.call(this,"destroy")},prev:function(a,b){return l._traverse.call(this,a,b,function(a,b,c){if(0<b)return a.push(c[b-1])})},next:function(a,b){return l._traverse.call(this,a,b,function(a,b,c){if(b<c.length-1)return a.push(c[b+1])})},_traverse:function(a,b,d){null==a&&(a="vertical");null==b&&(b=g);var f=k.aggregate(b);
var e=[];this.each(function(){var b=c.inArray(this,f[a]);return d(e,b,f[a])});return this.pushStack(e)},_invoke:function(a){this.each(function(){var b=t.getWaypointsByElement(this);return c.each(b,function(b,c){c[a]();return!0})});return this}};c.fn.waypoint=function(){var a=arguments[0];var b=2<=arguments.length?m.call(arguments,1):[];return l[a]?l[a].apply(this,b):"function"===typeof a?l.init.apply(this,arguments):c.isPlainObject(a)?l.init.apply(this,[null,a]):a?c.on("error",function(){alert("The "+
a+" method does not exist in jQuery Waypoints.")}):c.on("error",function(){alert("jQuery Waypoints needs a callback function or handler option.")})};c.fn.waypoint.defaults={context:g,continuous:!0,enabled:!0,horizontal:!1,offset:0,triggerOnce:!1};var k={refresh:function(){return c.each(p,function(a,b){return b.refresh()})},viewportHeight:function(){var a;return null!=(a=g.innerHeight)?a:q.height()},aggregate:function(a){var b;var d=n;a&&(d=null!=(b=p[c(a)[0]["waypoints-context-id"]])?b.waypoints:
void 0);if(!d)return[];var f={horizontal:[],vertical:[]};c.each(f,function(a,b){c.each(d[a],function(a,c){return b.push(c)});b.sort(function(a,b){return a.offset-b.offset});f[a]=c.map(b,function(a){return a.element});return f[a]=c.uniqueSort(f[a])});return f},above:function(a){null==a&&(a=g);return k._filter(a,"vertical",function(a,c){return c.offset<=a.oldScroll.y})},below:function(a){null==a&&(a=g);return k._filter(a,"vertical",function(a,c){return c.offset>a.oldScroll.y})},left:function(a){null==
a&&(a=g);return k._filter(a,"horizontal",function(a,c){return c.offset<=a.oldScroll.x})},right:function(a){null==a&&(a=g);return k._filter(a,"horizontal",function(a,c){return c.offset>a.oldScroll.x})},enable:function(){return k._invoke("enable")},disable:function(){return k._invoke("disable")},destroy:function(){return k._invoke("destroy")},extendFn:function(a,b){return l[a]=b},_invoke:function(a){var b=c.extend({},n.vertical,n.horizontal);return c.each(b,function(b,c){c[a]();return!0})},_filter:function(a,
b,d){var f=p[c(a)[0]["waypoints-context-id"]];if(!f)return[];var e=[];c.each(f.waypoints[b],function(a,b){if(d(f,b))return e.push(b)});e.sort(function(a,b){return a.offset-b.offset});return c.map(e,function(a){return a.element})}};c.waypoints=function(){var a=arguments[0];var b=2<=arguments.length?m.call(arguments,1):[];return k[a]?k[a].apply(null,b):k.aggregate.call(null,a)};c.waypoints.settings={resizeThrottle:100,scrollThrottle:30};return q.on("load.waypoints",function(){return c.waypoints("refresh")})})}).call(this);
PrimeFaces.widget.ExtWaypoint=PrimeFaces.widget.BaseWidget.extend({init:function(e){this._super(e);this.cfg=e;this.id=e.id;this.target=PrimeFaces.expressions.SearchExpressionFacade.resolveComponentsAsSelector(this.cfg.target);delete this.cfg.target;this.cfg.context&&(this.cfg.context=PrimeFaces.expressions.SearchExpressionFacade.resolveComponentsAsSelector(this.cfg.context));this.destroy().create()},destroy:function(){this.target.waypoint("destroy");return this},disable:function(){this.target.waypoint("disable");
return this},enable:function(){this.target.waypoint("enable");return this},create:function(){var e=this;this.target.waypoint(function(m){e.reached(m,this)},this.cfg)},refresh:function(){$.waypoints("refresh")},reached:function(e,m){this.hasBehavior("reached")&&(e={params:[{name:this.id+"_direction",value:e},{name:this.id+"_waypointId",value:$(m).attr("id")}],direction:e,waypoint:m},this.callBehavior("reached",e))}});
